sqlobject.tests.test_setters module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_setters module

class `sqlobject.tests.test_setters.` `SOTestSetters`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `firstName`
  `j` = so_test_setters
  property `lastName`
  property `name`
  `q` = so_test_setters
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_setters.SOTestSetters`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_setters'

`sqlobject.tests.test_setters.` `test_create`()